/// <reference types="google.maps" />
import { Observable } from 'rxjs';
import { IPosition } from '../../interfaces/position.interface';
import { MapMarkerModel } from '../../model/map.marker';
import { IMapData } from './interfaces/map-data.interface';
import { MapAddressType } from './map-address.type';
import { PlaceQuery } from './place-query-parameters.model';
import { Place } from './place.model';
import * as i0 from "@angular/core";
export declare class MapService {
    private readonly rendererFactory;
    private googleMapsKey;
    private googleMapsURL;
    private renderer;
    private scriptElement;
    private _updateLocations$;
    private _googleApiLoader$;
    onUpdateLocations: Observable<IMapData>;
    constructor();
    setGoogleMapsKey(key: string): void;
    getGoogleMapsKey(): string;
    setGoogleMapsURL(url: string): void;
    getGoogleMapsURL(): string;
    matchesGoogleMapsApiKey(googleMapsAPIKey: string): boolean;
    /**
     * Loads the Google Maps API, optionally reloading if already loaded unless `reloadApi` is set to `false`.
     *
     * @param {boolean} [reloadApi=true] - A flag to determine whether to reload the API if it has already been loaded. Defaults to `true`, meaning the API will be unloaded and loaded by default.
     * @return {Observable<boolean>} - An observable that emits `true` when the API has been successfully loaded.
     */
    loadGoogleApis(reloadApi?: boolean): Observable<boolean>;
    /**
     * Unloads the Google Maps API by removing associated script tags from the DOM and clearing the global `google` object.
     *
     * @return {Observable<boolean>} - An observable that emits `true` if the Google Maps API was successfully unloaded,
     * or `false` if the API was not loaded or an error occurred.
     *
     * @example
     * // To unsubscribe from the Google Maps API:
     * this.unloadGoogleMapApis().subscribe((result) => {
     *   console.log(result ? 'API unloaded successfully' : 'API unload failure');
     * });
     */
    unloadGoogleMapApis(): Observable<boolean>;
    buildMapMarker(id: string, icon: string, position: IPosition, radius?: number, customClass?: string, iconWidth?: number, iconHeight?: number, omitMarkerCircle?: boolean, anchor?: google.maps.Point): MapMarkerModel;
    getAddressObject(location: google.maps.LatLngLiteral): Observable<MapAddressType>;
    getMapAddressString(location: google.maps.LatLngLiteral): Observable<string>;
    getBatchAddresses(locations: google.maps.LatLngLiteral[]): Observable<string[]>;
    getCoordinatesFromAddress(address: string): Observable<{
        lat: number;
        lng: number;
    }>;
    findNearbyPlaces(query: PlaceQuery): Observable<Place[]>;
    /**
     * Builds a map marker by the provided index.
     *
     * @param {number} index - The index of the marker.
     * @param {PositionModel} position - The position of the marker.
     * @param {number} radius - The radius of the marker.
     * @return {MapMarkerModel} - The built map marker.
     */
    private buildMapMarkerByIndex;
    /**
     * Updates the locations and markers by emitting the provided payload.
     *
     * @param {{ locations: string[], markers: MapMarkerModel[] }} payload - The updated locations and markers.
     */
    updateLocations(payload: IMapData): void;
    /**
     * Moves a location and its corresponding marker from one index to another.
     *
     * @param {number} fromIndex - The current index of the location.
     * @param {number} toIndex - The target index to move the location to.
     * @param {string[]} locations - The array of locations.
     * @param {MapMarkerModel[]} markers - The array of map markers.
     */
    moveLocation(fromIndex: number, toIndex: number, locations: string[], markers: MapMarkerModel[]): void;
    /**
     * Removes a location and its corresponding marker by index.
     *
     * @param {number} index - The index of the location to be removed.
     * @param {string[]} locations - The array of locations.
     * @param {MapMarkerModel[]} markers - The array of map markers.
     */
    removeLocation(index: number, locations: string[], markers: MapMarkerModel[]): void;
    /**
     * Adds a new location to the existing set of locations.
     *
     * @param {Location} newLocation - The new location to add.
     * @param {string[]} locations - The array of locations.
     * @param {MapMarkerModel[]} markers - The array of map markers.
     * @return {void}
     */
    addLocation({ address, position }: {
        address: string;
        position: google.maps.LatLngLiteral;
    }, locations: string[], markers: MapMarkerModel[]): void;
    /**
     * Edits an existing location by updating its address and position.
     *
     * @param {Object} updatedLocation - The location to edit.
     * @param {number} updatedLocation.index - The index of the location to edit.
     * @param {string} updatedLocation.address - The new address.
     * @param {google.maps.LatLngLiteral} updatedLocation.position - The new position.
     * @param {string[]} locations - The array of locations.
     * @param {MapMarkerModel[]} markers - The array of map markers.
     * @return {void}
     */
    editLocation({ index, address, position }: {
        index: number;
        address: string;
        position: google.maps.LatLngLiteral;
    }, locations: string[], markers: MapMarkerModel[]): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<MapService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<MapService>;
}
